#
# spec file for package ghc-doclayout
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name doclayout
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.0.2
Release:        1.3
Summary:        A prettyprinting library for laying out text documents
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-text-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-hunit-devel
%endif

%description
Doclayout is a prettyprinting library for laying out text documents, with
several features not present in prettyprinting libraries designed for code.
It was designed for use in pandoc.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%dir %{_datadir}/%{pkg_name}-%{version}
%{_datadir}/%{pkg_name}-%{version}/README.md
%{_datadir}/%{pkg_name}-%{version}/changelog.md

%files devel -f %{name}-devel.files

%changelog
* Tue Mar 16 2021 psimons@suse.com
- Update doclayout to version 0.3.0.2.
  [#]# 0.3.0.2
  * NOINLINE `literal` instead of `fromString` (#2, sjakobi).
    This produces a further reduction in allocations and
    pandoc compile time.
* Sun Mar 14 2021 psimons@suse.com
- Update doclayout to version 0.3.0.1.
  [#]# 0.3.0.1
  * NOINLINE `fromString` (#1).
    @sjakobi reports that this change reduced total allocations
    for building pandoc-2.12 with GHC 8.10.4 by 8.5%% and reduced
    peak allocations are reduced from 3854MB to 3389MB.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu Feb 27 2020 psimons@suse.com
- Update doclayout to version 0.3.
  [#]# 0.3
  * Add foldlChar to signature of HasChars [API change].
  * Use foldlChar in realLength. This avoids a stack overflow
    we were getting with long strings in the previous version
    (with foldrChar).  See jgm/pandoc#6031.
  * Replace isBlank with isBreakable and improved startsWithBlank.
    Previously isBlank was used in the layout algorithm where
    what we really wanted was isBreakable.
  * Avoid unnecessary calculation in updateColumns.
  * Replace a right fold with a strict left fold.
  * Add strictness annotations in realLength and updateColumn.
* Sat Dec 21 2019 psimons@suse.com
- Add doclayout at version 0.2.0.1.
